@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-'''WebSocket Tunnel
-'''
+"""WebSocket Tunnel
+"""
 
 import asyncio
 import copy
@@ -19,8 +19,8 @@ from . import utils
 
 
 class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
-    '''WebSocket Client Support using exist connection 
-    '''
+    """WebSocket Client Support using exist connection"""
+
     def __init__(self, tunnel, url, headers=None, timeout=15):
         self._tunnel = tunnel
         self._url = url
@@ -30,33 +30,36 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
         compression_options = None
         if isinstance(headers, dict):
             headers = tornado.httputil.HTTPHeaders(headers)
-        request = tornado.httpclient.HTTPRequest(self._url,
-                                                 headers=headers,
-                                                 connect_timeout=timeout,
-                                                 request_timeout=timeout)
+        request = tornado.httpclient.HTTPRequest(
+            self._url, headers=headers, connect_timeout=timeout, request_timeout=timeout
+        )
         request = tornado.httpclient._RequestProxy(
-            request, tornado.httpclient.HTTPRequest._DEFAULTS)
-        super(WebSocketTunnelConnection,
-              self).__init__(request,
-                             on_message_callback=self.on_message,
-                             compression_options=compression_options)
+            request, tornado.httpclient.HTTPRequest._DEFAULTS
+        )
+        super(WebSocketTunnelConnection, self).__init__(
+            request,
+            on_message_callback=self.on_message,
+            compression_options=compression_options,
+        )
         self._patcher = self._patch_tcp_client(self._tunnel)
         self._patcher.patch()
-        self._buffer = b''
+        self._buffer = b""
         self._read_event = asyncio.Event()
 
     def _patch_tcp_client(self, tunn):
         TCPClient = tornado.tcpclient.TCPClient
 
-        async def connect(tcp_client,
-                          host,
-                          port,
-                          af=socket.AF_UNSPEC,
-                          ssl_options=None,
-                          max_buffer_size=None,
-                          source_ip=None,
-                          source_port=None,
-                          timeout=None):
+        async def connect(
+            tcp_client,
+            host,
+            port,
+            af=socket.AF_UNSPEC,
+            ssl_options=None,
+            max_buffer_size=None,
+            source_ip=None,
+            source_port=None,
+            timeout=None,
+        ):
             return tunnel.TunnelIOStream(tunn)
 
         class TCPClientPatchContext(object):
@@ -79,12 +82,14 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
         return TCPClientPatchContext(connect)
 
     async def headers_received(self, start_line, headers):
-        await super(WebSocketTunnelConnection,
-                    self).headers_received(start_line, headers)
+        await super(WebSocketTunnelConnection, self).headers_received(
+            start_line, headers
+        )
         if start_line.code != 101:
             utils.logger.error(
-                '[%s] Connect %s return %d' %
-                (self.__class__.__name__, self._url, start_line.code))
+                "[%s] Connect %s return %d"
+                % (self.__class__.__name__, self._url, start_line.code)
+            )
             self._connected = False
         else:
             self._connected = True
@@ -105,8 +110,9 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
             self._patcher.unpatch()
             return self._connected
         else:
-            utils.logger.warn('[%s] Connect %s timeout' %
-                              (self.__class__.__name__, self._url))
+            utils.logger.warn(
+                "[%s] Connect %s timeout" % (self.__class__.__name__, self._url)
+            )
             self._patcher.unpatch()
             return False
 
@@ -117,7 +123,7 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
             await self._read_event.wait()
             self._read_event.clear()
         buffer = self._buffer
-        self._buffer = b''
+        self._buffer = b""
         return buffer
 
     async def write(self, buffer):
@@ -129,8 +135,8 @@ class WebSocketTunnelConnection(tornado.websocket.WebSocketClientConnection):
 
 
 class WebSocketTunnel(tunnel.Tunnel):
-    '''WebSocket Tunnel
-    '''
+    """WebSocket Tunnel"""
+
     def __init__(self, tunnel, url, address):
         url = copy.copy(url)
         url.path = url.path.format(addr=address[0], port=address[1])
@@ -141,10 +147,12 @@ class WebSocketTunnel(tunnel.Tunnel):
         headers = {}
         auth_data = self._url.auth
         if auth_data:
-            headers['Proxy-Authorization'] = 'Basic %s' % auth.http_basic_auth(
-                *auth_data.split(':'))
-        self._upstream = WebSocketTunnelConnection(self._tunnel,
-                                                   str(self._url), headers)
+            headers["Proxy-Authorization"] = "Basic %s" % auth.http_basic_auth(
+                *auth_data.split(":")
+            )
+        self._upstream = WebSocketTunnelConnection(
+            self._tunnel, str(self._url), headers
+        )
         return await self._upstream.wait_for_connecting()
 
     async def read(self):
@@ -162,7 +170,7 @@ class WebSocketTunnel(tunnel.Tunnel):
 class WebSocketDownStream(utils.IStream):
     def __init__(self, handler):
         self._handler = handler
-        self._buffer = b''
+        self._buffer = b""
         self._read_event = asyncio.Event()
 
     def on_recv(self, buffer):
@@ -176,7 +184,7 @@ class WebSocketDownStream(utils.IStream):
             await self._read_event.wait()
             self._read_event.clear()
         buffer = self._buffer
-        self._buffer = b''
+        self._buffer = b""
         return buffer
 
     async def write(self, buffer):
@@ -190,20 +198,19 @@ class WebSocketDownStream(utils.IStream):
 
 
 class WebSocketTunnelServer(server.TunnelServer):
-    '''WebSocket Tunnel Server
-    '''
+    """WebSocket Tunnel Server"""
+
     def post_init(self):
         this = self
 
         class WebSocketProtocol(tornado.websocket.WebSocketProtocol13):
             async def accept_connection(self, handler):
                 if await self.handler.connect():
-                    await super(WebSocketProtocol,
-                                self).accept_connection(handler)
+                    await super(WebSocketProtocol, self).accept_connection(handler)
 
         class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
-            '''WebSocket Proxy Handler
-            '''
+            """WebSocket Proxy Handler"""
+
             def __init__(self, *args, **kwargs):
                 super(WebSocketProxyHandler, self).__init__(*args, **kwargs)
                 self._tun_conn = None
@@ -211,13 +218,12 @@ class WebSocketTunnelServer(server.TunnelServer):
                 self._downstream = None
 
             async def connect(self):
-                '''connect target server
-                '''
+                """connect target server"""
                 address = None
                 ret = re.match(this._listen_url.path, self.request.path)
                 if ret:
-                    addr = ret.groupdict().get('addr')
-                    port = ret.groupdict().get('port')
+                    addr = ret.groupdict().get("addr")
+                    port = ret.groupdict().get("port")
                     if addr and port and port.isdigit():
                         address = addr, int(port)
                 if not address:
@@ -225,25 +231,29 @@ class WebSocketTunnelServer(server.TunnelServer):
                     return False
                 auth_data = this._listen_url.auth
                 if auth_data:
-                    auth_data = auth_data.split(':')
+                    auth_data = auth_data.split(":")
                     for header in self.request.headers:
-                        if header == 'Proxy-Authorization':
+                        if header == "Proxy-Authorization":
                             value = self.request.headers[header]
                             auth_type, auth_value = value.split()
-                            if auth_type == 'Basic' and auth_value == auth.http_basic_auth(
-                                    *auth_data):
+                            if (
+                                auth_type == "Basic"
+                                and auth_value == auth.http_basic_auth(*auth_data)
+                            ):
                                 break
                     else:
                         utils.logger.info(
-                            '[%s] Connection to %s:%d refused due to wrong auth'
-                            %
-                            (self.__class__.__name__, address[0], address[1]))
-                        self.set_status(403, 'Forbidden')
+                            "[%s] Connection to %s:%d refused due to wrong auth"
+                            % (self.__class__.__name__, address[0], address[1])
+                        )
+                        self.set_status(403, "Forbidden")
                         return False
 
                 self._tun_conn = server.TunnelConnection(
-                    self.request.connection.context.address, address,
-                    this.final_tunnel and this.final_tunnel.address)
+                    self.request.connection.context.address,
+                    address,
+                    this.final_tunnel and this.final_tunnel.address,
+                )
                 self._tun_conn.on_open()
 
                 self._tunnel_chain = this.create_tunnel_chain()
@@ -252,29 +262,30 @@ class WebSocketTunnelServer(server.TunnelServer):
                     await self._tunnel_chain.create_tunnel(address)
                 except utils.TunnelError as e:
                     if not isinstance(e, utils.TunnelBlockedError):
-                        utils.logger.warn('[%s] Connect %s:%d failed: %s' %
-                                          (self.__class__.__name__, address[0],
-                                           address[1], e))
-                        self.set_status(504, 'Gateway timeout')
+                        utils.logger.warn(
+                            "[%s] Connect %s:%d failed: %s"
+                            % (self.__class__.__name__, address[0], address[1], e)
+                        )
+                        self.set_status(504, "Gateway timeout")
                     else:
-                        self.set_status(403, 'Forbidden')
+                        self.set_status(403, "Forbidden")
                     return False
                 self._downstream = WebSocketDownStream(self)
                 utils.AsyncTaskManager().start_task(
-                    this.forward_data_to_upstream(self._tun_conn,
-                                                  self._downstream,
-                                                  self._tunnel_chain.tail))
+                    this.forward_data_to_upstream(
+                        self._tun_conn, self._downstream, self._tunnel_chain.tail
+                    )
+                )
                 utils.AsyncTaskManager().start_task(
-                    this.forward_data_to_downstream(self._tun_conn,
-                                                    self._downstream,
-                                                    self._tunnel_chain.tail))
+                    this.forward_data_to_downstream(
+                        self._tun_conn, self._downstream, self._tunnel_chain.tail
+                    )
+                )
                 return True
 
             def get_websocket_protocol(self):
-                '''Override to connect target server
-                '''
-                websocket_version = self.request.headers.get(
-                    "Sec-WebSocket-Version")
+                """Override to connect target server"""
+                websocket_version = self.request.headers.get("Sec-WebSocket-Version")
                 if websocket_version in ("7", "8", "13"):
                     params = tornado.websocket._WebSocketParams(
                         ping_interval=self.ping_interval,
@@ -282,9 +293,7 @@ class WebSocketTunnelServer(server.TunnelServer):
                         max_message_size=self.max_message_size,
                         compression_options=self.get_compression_options(),
                     )
-                    return WebSocketProtocol(self,
-                                             mask_outgoing=True,
-                                             params=params)
+                    return WebSocketProtocol(self, mask_outgoing=True, params=params)
 
             async def on_message(self, message):
                 self._downstream.on_recv(message)
@@ -298,8 +307,9 @@ class WebSocketTunnelServer(server.TunnelServer):
                 self._tunnel_chain.close()
                 self._tunnel_chain = None
 
-        path = self._listen_url.path.format(addr=r'(?P<addr>[\w\.]+)',
-                                            port=r'(?P<port>\d+)')
+        path = self._listen_url.path.format(
+            addr=r"(?P<addr>[\w\.-]+)", port=r"(?P<port>\d+)"
+        )
         self._listen_url.path = path
         handlers = [
             (path, WebSocketProxyHandler),
@@ -308,10 +318,11 @@ class WebSocketTunnelServer(server.TunnelServer):
 
     def start(self):
         self._app.listen(self._listen_url.port, self._listen_url.host)
-        utils.logger.info('[%s] WebSocket server is listening on %s:%d' %
-                          (self.__class__.__name__, self._listen_url.host,
-                           self._listen_url.port))
+        utils.logger.info(
+            "[%s] WebSocket server is listening on %s:%d"
+            % (self.__class__.__name__, self._listen_url.host, self._listen_url.port)
+        )
 
 
-registry.tunnel_registry.register('ws', WebSocketTunnel)
-registry.server_registry.register('ws', WebSocketTunnelServer)
+registry.tunnel_registry.register("ws", WebSocketTunnel)
+registry.server_registry.register("ws", WebSocketTunnelServer)
